# Changelog

## 0.1.3

- Add Development section to README

## 0.1.0 (2026-03-13)

- Initial release
- `JsonFormatter` for structured JSON log output
- `setup()` for quick root logger configuration
- Exception traceback included as `exception` field
- Static `extra_fields` support
- Extra record attributes merged into JSON output
